@@ -7,7 +7,7 @@ from django.contrib.contenttypes.fields import GenericRelation
 from django.db import models
 from django.utils.text import slugify
 from django.contrib.postgres.fields import JSONField
-
+from django.utils.translation import gettext_lazy as _
 from .fields import ListField, NotNullRestrictedCharField
 
 
@@ -124,7 +124,7 @@ class RequestLog(models.Model):
     """
 
     request_id = models.UUIDField(
-        default=uuid.uuid4, help_text="Unique id of the request."
+        default=uuid.uuid4, help_text=_("Unique id of the request.")
     )
     response_time = models.DurationField()
     ip_address = models.GenericIPAddressField(blank=True)
@@ -138,8 +138,28 @@ class Record(models.Model):
     A generic record model.
     """
 
+    NEW = "NEW"
+    OLD = "OLD"
+
+    PENDING = 0
+    CANCELLED = 1
+    CONFIRMED = 2
+
+    RECORD_TYPE_CHOICES = ((NEW, "New"), (OLD, "Old"))
+    RECORD_STATUS_CHOICES = (
+        (PENDING, "Pending"),
+        (CANCELLED, "Cancelled"),
+        (CONFIRMED, "Confirmed"),
+    )
+
     title = NotNullRestrictedCharField()
     items = ListField()
+    record_type = models.CharField(
+        default=NEW, max_length=5, choices=RECORD_TYPE_CHOICES
+    )
+    record_status = models.PositiveSmallIntegerField(
+        default=PENDING, choices=RECORD_STATUS_CHOICES
+    )
 
 
 class ItemList(models.Model):
